// The origin is the corner of the battery cover on the back of the device.
// X points to the right of the screen.  Y points to the top of the screen.  Z
// points out of the screen.

// The design consists of separate parts.  This variable can be 1 or 2.
part = 0;

$fs = 0.01;
$fn = 64;

// The height from the bottom to where the 2 halves split.
split_height = 36.04;

if (part == 1)
  intersection() {
    translate([-200, 200, split_height])
      rotate([180, 0, 0])
        cube(400);
    full();
  }
else if (part == 2)
  intersection() {
    translate([-200, -200, 0])
      cube(400);
    translate([0, 0, -split_height])
      full();
  }
else
  full();

module full() {
  difference() {
    // The outline.
    intersection() {
      mirror([1, 0, 0])
        mirror([0, 1, 0])
        translate([0, 0, -200])
        cube([400, 400, 400]);
      minkowski() {
        intersection() {
          linear_extrude(200, center = true)
            polygon([[-16.8, 5.0],
                     [-12.0, -26.8],
                     [5.0, -26.8],
                     [5.0, 5.0]]);
          rotate([0, -90, 0])
            linear_extrude(200, center = true)
              polygon([[5.0, 5.0],
                       [5.0, -24.8],
                       [60.0, -24.8],
                       [65.0, -7.6],
                       [65.6, 5.0]]);
        }
        sphere(5.0);
      }
    }

    // The vertical slot.
    rotate([90, 0, -90])
      difference() {
        linear_extrude(10.4, center = true)
          polygon([[-4.0, 1.0],
                   [26.2, 1.0],
                   [28.2, 3.0],
                   [28.2, 60.0],
                   [27.0, 62.6],
                   [23.0, 64.8],
                   [6.6, 69.4],
                   [-4.0, 69.4]]);
        translate([0, 0, 1.4])
          linear_extrude(2.2, convexity = 4)
            polygon([[200.0, -200.0],
                     [20.8, 0.0],
                     [24.8, 4.0],
                     [25.4, 3.4],
                     [26.6, 3.4],
                     [26.6, 6.8],
                     [27.8, 8.0],
                     [27.8, 63.6],
                     [-200.0, 63.6],
                     [200.0, 200.0]],
                    convexity = 4);
        rotate([90, 0, 90])
          linear_extrude(53.6, center = true)
            polygon([[0.4, 0.0],
                     [2.0, 1.6],
                     [2.0, 3.4],
                     [0.4, 5.0],
                     [-200.0, 0.0]]);
      }

    // The horizontal slot.
    rotate([90, -90, 0])
      intersection() {
        translate([-200.0, 4.4, -200.0])
          cube(400.0);
        minkowski(convexity = 3) {
          linear_extrude(0.4, center = true)
            polygon([[2.4, -200.0],
                     [2.4, 16.0],
                     [split_height, 17.4],
                     [67.0, 16.2],
                     [67.0, -200.0]]);
          difference() {
            cylinder(h = 7.6, r = 1.4, center = true);
            rotate_extrude(convexity = 3)
              hull() {
                translate([1.4, 1.8])
                  circle(1.0);
                translate([1.4, 1.4])
                  circle(1.0);
              }
          }
        }
      }

    // The screw hole.
    translate([-10, -12.5, split_height]) {
      cylinder(h = 200.0, r = 1.5, center = true);
      translate([0, 0, 4])
        rotate([0, 0, 90])
        cylinder(h = 200.0, r = 2 / sqrt(3) * 2.5, $fn = 6);
      translate([0, 0, -4])
        rotate([180, 0, 0])
          cylinder(h = 200.0, r = 3.15);
    }
  }
}
